        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 17 <strong>control</strong><br>0,4,5,8,10,12,19,21,23,25,26,27,29,32,39,43,44';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 13 <br>2,7,9,15,22,28,31,33,35,38,41,46,47';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 9 <br>3,6,13,17,18,20,34,37,42';}
       if(rr==5 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 7 <br>14,24,36,40,48,49,50';}
       if(rr==5 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 5 <br>1,11,16,30,45';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 17 <strong>control</strong><br>0,4,5,8,10,12,19,21,23,25,26,27,29,32,39,43,44';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 13 <br>2,7,9,15,22,28,31,33,35,38,41,46,47';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 9 <br>3,6,13,17,18,20,34,37,42';}
       if(rr==40 && cc==4){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 7 <br>14,24,36,40,48,49,50';}
       if(rr==40 && cc==5){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 5 <br>1,11,16,30,45';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 17 <strong>control</strong><br>0,4,5,8,10,12,19,21,23,25,26,27,29,32,39,43,44';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 13 <br>2,7,9,15,22,28,31,33,35,38,41,46,47';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 9 <br>3,6,13,17,18,20,34,37,42';}
       if(rr==41 && cc==4){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 7 <br>14,24,36,40,48,49,50';}
       if(rr==41 && cc==5){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 5 <br>1,11,16,30,45';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 17 <strong>control</strong><br>0,4,5,8,10,12,19,21,23,25,26,27,29,32,39,43,44';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 13 <br>2,7,9,15,22,28,31,33,35,38,41,46,47';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 9 <br>3,6,13,17,18,20,34,37,42';}
       if(rr==42 && cc==4){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 7 <br>14,24,36,40,48,49,50';}
       if(rr==42 && cc==5){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 5 <br>1,11,16,30,45';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>43</strong> miembros: 17 <strong>control</strong><br>0,4,5,8,10,12,19,21,23,25,26,27,29,32,39,43,44';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>22</strong> miembros: 13 <br>2,7,9,15,22,28,31,33,35,38,41,46,47';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 9 <br>3,6,13,17,18,20,34,37,42';}
       if(rr==43 && cc==4){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>40</strong> miembros: 7 <br>14,24,36,40,48,49,50';}
       if(rr==43 && cc==5){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260613 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>30</strong> miembros: 5 <br>1,11,16,30,45';}
}
